#[non_exhaustive]pub enum FeatureType {
Continuous(f64, f64),
Categorical(usize),
Ordinal(usize),
Binary,
}Expand description
Describes the type and parameters of a single feature column.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Continuous(f64, f64)
Continuous Gaussian feature with given (mean, std)
Categorical(usize)
Categorical feature with the given number of categories
Ordinal(usize)
Ordinal feature with the given number of levels (0 ..= n_levels-1)
Binary
Binary Bernoulli feature