#[non_exhaustive]pub enum SamplerStrategy {
Sequential,
Random,
Stratified,
WeightedRandom {
weights: Vec<f64>,
},
}Expand description
Strategy used by the mini-batch sampler to select samples.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Sequential
Iterate through the dataset in order.
Random
Randomly shuffle all indices, then iterate sequentially over the shuffled order.
Stratified
Each batch maintains the same label proportions as the full dataset.
WeightedRandom
Sample indices according to per-example weights (with replacement).