pub struct StreamingIterator { /* private fields */ }Expand description
Iterator over streaming dataset chunks
Implementations
Sourceimpl StreamingIterator
impl StreamingIterator
Sourcepub fn from_csv<P: AsRef<Path>>(path: P, config: StreamConfig) -> Result<Self>
pub fn from_csv<P: AsRef<Path>>(path: P, config: StreamConfig) -> Result<Self>
Create a new streaming iterator from a CSV file
Sourcepub fn from_binary<P: AsRef<Path>>(
path: P,
n_features: usize,
config: StreamConfig,
) -> Result<Self>
pub fn from_binary<P: AsRef<Path>>( path: P, n_features: usize, config: StreamConfig, ) -> Result<Self>
Create a new streaming iterator from a binary file
Sourcepub fn from_generator<F>(
generator: F,
total_samples: usize,
n_features: usize,
config: StreamConfig,
) -> Result<Self>
pub fn from_generator<F>( generator: F, total_samples: usize, n_features: usize, config: StreamConfig, ) -> Result<Self>
Create a streaming iterator from a data generator function
Sourcepub fn next_chunk(&mut self) -> Result<Option<DataChunk>>
pub fn next_chunk(&mut self) -> Result<Option<DataChunk>>
Get the next chunk from the stream
Sourcepub fn stats(&self) -> StreamStats
pub fn stats(&self) -> StreamStats
Get streaming statistics