pub struct Dataset {
pub data: Array2<f64>,
pub target: Option<Array1<f64>>,
pub targetnames: Option<Vec<String>>,
pub featurenames: Option<Vec<String>>,
pub feature_descriptions: Option<Vec<String>>,
pub description: Option<String>,
pub metadata: HashMap<String, String>,
}Expand description
Represents a dataset with features, optional targets, and metadata
The Dataset struct is the core data structure for managing machine learning datasets. It stores the feature matrix, optional target values, and rich metadata including feature names, descriptions, and arbitrary key-value pairs.
Examples
use scirs2_core::ndarray::Array2;
use scirs2_datasets::utils::Dataset;
let data = Array2::from_shape_vec((3, 2), vec![1.0, 2.0, 3.0, 4.0, 5.0, 6.0]).expect("Operation failed");
let dataset = Dataset::new(data, None)
.with_featurenames(vec!["feature1".to_string(), "feature2".to_string()])
.with_description("Sample dataset".to_string());
assert_eq!(dataset.n_samples(), 3);
assert_eq!(dataset.n_features(), 2);Fields
data: Array2<f64>Features/data matrix (n_samples, n_features)
target: Option<Array1<f64>>Optional target values
targetnames: Option<Vec<String>>Optional target names for classification problems
featurenames: Option<Vec<String>>Optional feature names
feature_descriptions: Option<Vec<String>>Optional descriptions for each feature
description: Option<String>Optional dataset description
metadata: HashMap<String, String>Optional dataset metadata
Implementations
Sourceimpl Dataset
impl Dataset
Sourcepub fn new(data: Array2<f64>, target: Option<Array1<f64>>) -> Self
pub fn new(data: Array2<f64>, target: Option<Array1<f64>>) -> Self
Create a new dataset with the given data and target
Arguments
data- The feature matrix (n_samples, n_features)target- Optional target values (n_samples,)
Returns
A new Dataset instance with empty metadata
Examples
use scirs2_core::ndarray::{Array1, Array2};
use scirs2_datasets::utils::Dataset;
let data = Array2::zeros((100, 5));
let target = Some(Array1::zeros(100));
let dataset = Dataset::new(data, target);Sourcepub fn from_metadata(
data: Array2<f64>,
target: Option<Array1<f64>>,
metadata: DatasetMetadata,
) -> Self
pub fn from_metadata( data: Array2<f64>, target: Option<Array1<f64>>, metadata: DatasetMetadata, ) -> Self
Sourcepub fn with_targetnames(self, targetnames: Vec<String>) -> Self
pub fn with_targetnames(self, targetnames: Vec<String>) -> Self
Sourcepub fn with_featurenames(self, featurenames: Vec<String>) -> Self
pub fn with_featurenames(self, featurenames: Vec<String>) -> Self
Sourcepub fn with_feature_descriptions(self, featuredescriptions: Vec<String>) -> Self
pub fn with_feature_descriptions(self, featuredescriptions: Vec<String>) -> Self
Sourcepub fn with_description(self, description: String) -> Self
pub fn with_description(self, description: String) -> Self
Sourcepub fn with_metadata(self, key: &str, value: &str) -> Self
pub fn with_metadata(self, key: &str, value: &str) -> Self
Sourcepub fn n_features(&self) -> usize
pub fn n_features(&self) -> usize
Sourcepub fn has_target(&self) -> bool
pub fn has_target(&self) -> bool
Sourcepub fn featurenames(&self) -> Option<&Vec<String>>
pub fn featurenames(&self) -> Option<&Vec<String>>
Get a reference to the feature names if available
Returns
Optional reference to feature names vector
Sourcepub fn targetnames(&self) -> Option<&Vec<String>>
pub fn targetnames(&self) -> Option<&Vec<String>>
Sourcepub fn description(&self) -> Option<&String>
pub fn description(&self) -> Option<&String>
Get a reference to the dataset description if available
Returns
Optional reference to dataset description
Sourcepub fn set_metadata(&mut self, key: &str, value: &str)
pub fn set_metadata(&mut self, key: &str, value: &str)